﻿// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
angular.module('smartHrass', ['ionic', 'smartHrass.controllers', 'smartHrass.services'])
    .run(function ($ionicPlatform, $rootScope, cmUtil, $state) {
        $ionicPlatform.ready(function() {
            // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
            // for form inputs)
            var cordova = window.cordova;
            if (cordova && cordova.plugins && cordova.plugins.Keyboard) {
                cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
                cordova.plugins.Keyboard.disableScroll(true);
            }
            if (window.StatusBar) {
                // org.apache.cordova.statusbar required
                window.StatusBar.styleLightContent();
            }

            //bakck button to exit
            $ionicPlatform.registerBackButtonAction(function (e) {
                if ($state.current.name !== "tab.index" && $state.current.name !== "user-reauth") {
                    $rootScope.$ionicGoBack();
                    return false;
                }

                if ($rootScope.backButtonPressedOnceToExit) {
                    ionic.Platform.exitApp();
                } else {
                    $rootScope.backButtonPressedOnceToExit = true;
                    if (window.plugins.toast) {
                        window.plugins.toast.showShortBottom("再按返回键退出程序");
                    }
                    setTimeout(function () {
                        $rootScope.backButtonPressedOnceToExit = false;
                    }, 2000);
                }
                e.preventDefault();
                return false;
            }, 101);

            //check user login
            cmUtil.get("/user/LoginCheck", null, function(res) {
                if (res.data.user) {
                    /*cmUtil.reAuthState(res.data.user); //cancel user reauth
                    $state.transitionTo("user-reauth");*/
                    cmUtil.setLoginState(res.data.user);
                }
            });
            cmUtil.checkUpgrade();
        });

        //stateChange event check user auth set
        $rootScope.$on("$stateChangeStart", function (event, toState) {
            if (toState.authRequired && !cmUtil.isLogined()) {
                $state.transitionTo("user-login");
                event.preventDefault();
            }
        });
    })
    .config(function($stateProvider, $urlRouterProvider, $ionicConfigProvider) {
        //set tabs style keep the same
        $ionicConfigProvider.tabs.position('bottom');
        $ionicConfigProvider.tabs.style("standard");

        // Ionic uses AngularUI Router which uses the concept of states
        // Learn more here: https://github.com/angular-ui/ui-router
        $stateProvider
            .state('user-login', {
                url: '/user-login',
                templateUrl: 'templates/user-login.html',
                controller: 'UserLoginCtrl'
            })
            .state('user-reauth', {
                url: '/user-reauth',
                templateUrl: 'templates/user-reauth.html',
                controller: 'UserReAuthCtrl'
            })
            .state('tab', {
                abstract: true,
                templateUrl: 'templates/tabs.html',
                controller: function($scope, $state) { $scope.$state = $state; }
            })
            .state('tab.index', {
                url: '/',
                views: { 'tab-index': { templateUrl: 'templates/index.html', controller: 'IndexCtrl' } }
            })
            .state('tab.qry-inspay', {
                url: '/qry-inspay',
                views: { 'tab-index': { templateUrl: 'templates/qry-inspay.html' } }
            })
            .state('tab.qry-medact', {
                url: '/qry-medact',
                views: { 'tab-index': { templateUrl: 'templates/qry-medact.html' } }
            })
            .state('tab.qry-retire', {
                url: '/qry-retire',
                views: { 'tab-index': { templateUrl: 'templates/qry-retire.html' } }
            })
            .state('tab.tc-pen', {
                url: '/tc-pen',
                views: { 'tab-index': { templateUrl: 'templates/tc-pen.html' } }
            })
            .state('tab.tc-psinfo', {
                url: '/tc-psinfo',
                authRequired: true,
                views: { 'tab-index': { templateUrl: 'templates/tc-psinfo.html', controller: 'CommonSocSrtCtrl', business: 'TcPersonalInfo' } }
            })
            .state('tab.tc-insured', {
                url: '/tc-insured',
                authRequired: true,
                views: { 'tab-index': { templateUrl: 'templates/tc-insured.html', controller: 'CommonSocSrtCtrl', business: 'TcInsuredInfo' } }
            })
            .state('tab.tc-paydt', {
                url: '/tc-paydt',
                authRequired: true,
                views: { 'tab-index': { templateUrl: 'templates/tc-paydt.html', controller: 'CommonSocSrtCtrl', business: 'TcPaymentDetail' } }
            })
            .state('tab.tc-benft', {
                url: '/tc-benft',
                authRequired: true,
                views: { 'tab-index': { templateUrl: 'templates/tc-benft.html', controller: 'CommonSocSrtCtrl', business: 'TcBenefitInfo' } }
            })
            .state('tab.resident-payment', {
                url: '/resident-payment',
                views: { 'tab-index': { templateUrl: 'templates/resident-payment.html', controller: 'ResidentPaymentQryCtrl' } }  //by felix in Jan.4 2017
            })
            .state('tab.recruit', {
                url: '/recruit',
                views: { 'tab-index': { templateUrl: 'templates/recruit.html', controller: 'CommonSocSrtCtrl', business: 'RecruitmentList' } }
            })
            .state('tab.sitenav', {
                url: '/sitenav',
                views: { 'tab-index': { templateUrl: 'templates/sitenav.html', controller: 'SiteNavCtrl' } }
            })
            .state('tab.user-basic', {
                url: '/user-basic',
                authRequired: true,
                views: { 'tab-index': { templateUrl: 'templates/user-basic.html', controller: 'CommonSocSrtCtrl', business: 'GetUserBasic' } }
            })
            .state('tab.user-insured', {
                url: '/user-insured',
                authRequired: true,
                views: { 'tab-index': { templateUrl: 'templates/user-insured.html', controller: 'CommonSocSrtCtrl', business: 'GetUserInsured' } }
            })
            .state('tab.ins-changes', {
                url: '/ins-changes',
                authRequired: true,
                views: { 'tab-index': { templateUrl: 'templates/ins-changes.html', controller: 'CommonSocSrtCtrl', business: 'GetInsChanges' } }
            })
            .state('tab.med-in', {
                url: '/med-in',
                authRequired: true,
                views: { 'tab-index': { templateUrl: 'templates/med-in.html', controller: 'CommonMonthQryCtrl', business: 'MedicalInDetail' } }
            })
            .state('tab.med-pay', {
                url: '/med-pay',
                authRequired: true,
                views: { 'tab-index': { templateUrl: 'templates/med-pay.html', controller: 'CommonMonthQryCtrl', business: 'MedicalPayDetail' } }
            })
            .state('tab.pen-ledger', {
                url: '/pen-ledger',
                authRequired: true,
                views: { 'tab-index': { templateUrl: 'templates/pen-ledger.html', controller: 'CommonSocSrtCtrl', business: 'PensionLedger' } }
            })
            .state('tab.pen-yearbk', {
                url: '/pen-yearbk',
                authRequired: true,
                views: { 'tab-index': { templateUrl: 'templates/pen-yearbk.html', controller: 'PenYearStdBkCtrl' } }
            })
            .state('tab.wth-agree', {
                url: '/wth-agree',
                authRequired: true,
                views: { 'tab-index': { templateUrl: 'templates/wth-agree.html', controller: 'CommonSocSrtCtrl', business: 'WithholdAgreementInfo' } }
            })
            .state('tab.wth-pay', {
                url: '/wth-pay',
                authRequired: true,
                views: { 'tab-index': { templateUrl: 'templates/wth-pay.html', controller: 'CommonSocSrtCtrl', business: 'WithholdPayInfo' } }
            })
            .state('tab.wth-payyear', {
                url: '/wth-payyear',
                authRequired: true,
                views: { 'tab-index': { templateUrl: 'templates/wth-payyear.html', controller: 'CommonSocSrtCtrl', business: 'WithholdPayYearInfo' } }
            })
            .state('tab.pen-retiree', {
                url: '/pen-retiree',
                authRequired: true,
                views: { 'tab-index': { templateUrl: 'templates/pen-retiree.html', controller: 'CommonSocSrtCtrl', business: 'PensionRetireeInfo' } }
            })
            .state('tab.pen-change', {
                url: '/pen-change',
                authRequired: true,
                views: { 'tab-index': { templateUrl: 'templates/pen-change.html', controller: 'CommonSocSrtCtrl', business: 'PensionChangeHis' } }
            })
            .state('tab.pen-treat', {
                url: '/pen-treat',
                authRequired: true,
                views: { 'tab-index': { templateUrl: 'templates/pen-treat.html', controller: 'CommonMonthQryCtrl', business: 'PensionTreatmentInfo' } }
            })
            .state('tab.ins-pay', {
                url: '/ins-pay/:type',
                authRequired: true,
                views: { 'tab-index': { templateUrl: 'templates/ins-pay.html', controller: 'CommonInsPaymentCtrl' } }
            })
            .state('tab.med-balance', {
                url: '/med-balance',
                authRequired: true,
                views: { 'tab-index': { templateUrl: 'templates/med-balance.html', controller: 'CommonSocSrtCtrl', business: 'MedAcountBalance' } }
            })
            .state('tab.socsrt', {
                url: '/socsrt',
                views: { 'tab-socsrt': { templateUrl: 'templates/socsrt.html', controller: 'SocSrtCtrl' } }
            })
            .state('tab.card-info', {
                url: '/card-info',
                authRequired: true,
                views: { 'tab-socsrt': { templateUrl: 'templates/card-info.html', controller: 'CommonSocSrtCtrl', business: 'QuerySocCardInfo' } }
            })
            .state('tab.socart-dt', {
                url: '/socart-dt/:type/:id',
                views: { 'tab-socsrt': { templateUrl: 'templates/ptart-dt.html', controller: 'PtArticleDetailCtrl' } }
            })
            .state('tab.more', {
                url: '/more',
                views: { 'tab-more': { templateUrl: 'templates/more.html' } }
            })
            .state('tab.art-list', {
                url: '/art-list/:type',
                views: { 'tab-more': { templateUrl: 'templates/art-list.html', controller: 'CommonArtListCtrl' } }
            })
            .state('tab.art-detail', {
                url: '/art-detail/:type/:id',
                views: { 'tab-more': { templateUrl: 'templates/art-detail.html', controller: 'CommonArtDetailCtrl' } }
            })
            .state('tab.guide', {
                url: '/guide',
                views: { 'tab-more': { templateUrl: 'templates/guide.html' } }
            })
            .state('tab.notice', {
                url: '/notice',
                loadUrl: '/guide/NoticeList',
                views: { 'tab-more': { templateUrl: 'templates/notice.html', controller: 'PtArticleListCtrl' } }
            })
            .state('tab.hotque', {
                url: '/hotque',
                loadUrl: '/guide/HostQuestionList',
                views: { 'tab-more': { templateUrl: 'templates/hotque.html', controller: 'PtArticleListCtrl' } }
            })
            .state('tab.ptart-dt', {
                url: '/ptart-dt/:type/:id',
                views: { 'tab-more': { templateUrl: 'templates/ptart-dt.html', controller: 'PtArticleDetailCtrl' } }
            })
            .state('tab.my', {
                url: '/my',
                authRequired: true,
                views: { 'tab-my': { templateUrl: 'templates/my.html', controller: 'MySetCtrl' } }
            })
            .state('tab.about', {
                url: '/about',
                views: { 'tab-my': { templateUrl: 'templates/about.html', controller: 'AboutAppCtrl' } }
            })
            .state('frame-page', {
                url: '/frame/:title/:url',
                templateUrl: 'templates/frame-page.html', controller: 'FramePageCtrl'
            });

        // if none of the above states are matched, use this as the fallback
        $urlRouterProvider.otherwise('/');
    })
    .filter('strDate', function() {
        return function (input) {
            if (!input || input.indexOf("-") >= 0) return input;
            return input.length > 6 ? input.substr(0, 4) + "-" + input.substr(4, 2) + "-" + input.substr(6, 2)
                : input.substr(0, 4) + "-" + input.substr(4, 2);
        };
    });
