﻿angular.module('smartHrass.services', [])
    .factory('cmUtil', function ($http, $httpParamSerializer, $ionicPopup, $ionicLoading, $filter) {
        var serverHost = "http://zhrs.dy.reefoo.cn:7000";
        if (location.protocol !== "file:") {
            serverHost = location.origin;
        }

        var cmUtil = {
            get: function(url, data, callback) {
                if (data) {
                    if (typeof(data) == "object") url += "?" + $httpParamSerializer(data);
                    else url += "?" + data;
                }
                $http.get(serverHost + url).then(function(res) {
                    if (res.data.error) $ionicPopup.alert({ title: '出错提示', template: res.data.error });
                    if (callback) callback(res);
                }, function(er) {
                    $ionicPopup.alert({ title: '请求异常', template: er.status + er.statusText });
                });
            },
            post: function(url, data, callback) {
                $ionicLoading.show();
                //if (data && typeof (data) == "object") data = $httpParamSerializer(data);
                $http.post(serverHost + url, data).then(function(res) {
                    $ionicLoading.hide();
                    if (res.data.error) $ionicPopup.alert({ title: '出错提示', template: res.data.error });
                    if (callback) callback(res);
                }, function(er) {
                    $ionicLoading.hide();
                    $ionicPopup.alert({ title: '请求异常', template: er.status + er.statusText });
                });
            },
            //popup
            alert: function (msg, callBack) {
                $ionicPopup.alert({ template: msg, okText: "确定" }).then(function() {
                    if (callBack) callBack();
                });
            },
            confirm: function(msg, okCall) {
                $ionicPopup.confirm({
                    template: msg,
                    cancelText: "取消",
                    okText: "确定"
                }).then(function (sel) {
                    if (sel && okCall) okCall();
                });
            },

            //user auth
            setLoginState: function(userInfo) {
                sessionStorage.setItem("loginUserInfo", userInfo);
            },
            isLogined: function() {
                var userInfo = sessionStorage.getItem("loginUserInfo");
                return userInfo != null;
            },
            removeLoginState: function() {
                sessionStorage.removeItem("loginUserInfo");
            },
            reAuthState: function (setVal) {
                if (setVal == undefined) return sessionStorage.getItem("reAuthInfo");
                else {
                    sessionStorage.setItem("reAuthInfo", setVal);
                    return null;
                }
            },
            getAppVersion: function(callback) {
                if (!window.cordova || !window.cordova.getAppVersion) return;
                window.cordova.getAppVersion.getVersionNumber().then(callback);
            },
            checkUpgrade: function (nonAlert) {
                cmUtil.getAppVersion(function (version) {
                    $http.get(serverHost + "/app/version?" + new Date().getTime()).then(function (res) {
                        var latestVersion = res.data.latestVersion;
                        if (latestVersion && latestVersion > version) {
                            var upFun = function () {
                                window.open(serverHost + "/app", "_system");
                            };
                            if (res.data.mustUpgrade) {
                                cmUtil.alert("有新版本 " + latestVersion + "，必须升级才能继续使用！", upFun);
                            } else {
                                cmUtil.confirm("有新版本 " + latestVersion + " 可用，现在更新吗？", upFun);
                            }
                        } else {
                            if (nonAlert) $ionicPopup.alert({ template: "已经是最新版本" });
                        }
                    }, function (er) {
                        console.error("Check upgrade error:" + er.status + er.statusText);
                    });
                });
            },

            //date util
            yearList: function(count) {
                var format = "yyyy";
                var dt = new Date();
                var dtList = [$filter('date')(dt, format)];
                for (var i = 1; i < count; i++) {
                    dt.setFullYear(dt.getFullYear() - 1);
                    dtList.push($filter('date')(dt, format));
                }
                return dtList;
            },
            monthList: function(count, firstnu) {
                var dtList = [];
                if (firstnu) dtList.push('');
                var format = "yyyyMM";
                var dt = new Date();
                dt.setDate(1);
                dtList.push($filter('date')(dt, format));
                for (var i = 1; i < count; i++) {
                    dt.setMonth(dt.getMonth() - 1);
                    dtList.push($filter('date')(dt, format));
                }
                return dtList;
            }
        };
        return cmUtil;
    });
